aboutsummaryrefslogtreecommitdiffstats
path: root/examples/pdf-count-strings.cc
diff options
context:
space:
mode:
Diffstat (limited to 'examples/pdf-count-strings.cc')
-rw-r--r--examples/pdf-count-strings.cc9
1 files changed, 4 insertions, 5 deletions
diff --git a/examples/pdf-count-strings.cc b/examples/pdf-count-strings.cc
index b5091a86..3b78ac76 100644
--- a/examples/pdf-count-strings.cc
+++ b/examples/pdf-count-strings.cc
@@ -1,8 +1,7 @@
//
// This example illustrates the use of QPDFObjectHandle::TokenFilter
// with filterPageContents. See also pdf-filter-tokens.cc for an
// example that uses QPDFObjectHandle::TokenFilter with
// addContentTokenFilter.
//
#include <iostream>
@@ -108,14 +107,14 @@ int main(int argc, char* argv[])
if (pageno % 2)
{
// Ignore output for odd pages.
- ph.filterPageContents(&counter);
+ ph.filterContents(&counter);
}
else
{
// Write output to stdout for even pages.
Pl_StdioFile out("stdout", stdout);
std::cout << "% Contents of page " << pageno << std::endl;
- ph.filterPageContents(&counter, &out);
+ ph.filterContents(&counter, &out);
std::cout << "\n% end " << pageno << std::endl;
}
std::cout << "Page " << pageno
@@ -1,8 +1,7 @@
//
// This example illustrates the use of QPDFObjectHandle::TokenFilter
-// with filterPageContents. See also pdf-filter-tokens.cc for an
-// example that uses QPDFObjectHandle::TokenFilter with
-// addContentTokenFilter.
+// with filterContents. See also pdf-filter-tokens.cc for an example
+// that uses QPDFObjectHandle::TokenFilter with addContentTokenFilter.
//
#include <iostream>